"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JwtAuthenticateGuard = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const jsonwebtoken_1 = require("jsonwebtoken");
const sdk_nestjs_monitoring_1 = require("@multiversx/sdk-nestjs-monitoring");
const sdk_nestjs_common_1 = require("@multiversx/sdk-nestjs-common");
const no_auth_1 = require("./decorators/no.auth");
let JwtAuthenticateGuard = class JwtAuthenticateGuard {
    constructor(mxnestConfigService) {
        this.mxnestConfigService = mxnestConfigService;
    }
    async canActivate(context) {
        const noAuthMetadata = sdk_nestjs_common_1.DecoratorUtils.getMethodDecorator(no_auth_1.NoAuthOptions, context.getHandler());
        if (noAuthMetadata) {
            return true;
        }
        const headers = sdk_nestjs_common_1.ExecutionContextUtils.getHeaders(context);
        const request = sdk_nestjs_common_1.ExecutionContextUtils.getRequest(context);
        const authorization = headers['authorization'];
        if (!authorization) {
            return false;
        }
        const jwt = authorization.replace('Bearer ', '');
        const profiler = new sdk_nestjs_monitoring_1.PerformanceProfiler();
        try {
            const jwtSecret = this.mxnestConfigService.getJwtSecret();
            request.jwt = await new Promise((resolve, reject) => {
                (0, jsonwebtoken_1.verify)(jwt, jwtSecret, (err, decoded) => {
                    if (err) {
                        reject(err);
                    }
                    resolve(Object.assign(Object.assign({}, decoded.user), decoded));
                });
            });
        }
        catch (error) {
            const message = error === null || error === void 0 ? void 0 : error.message;
            if (message) {
                profiler.stop();
                request.res.set('X-Jwt-Auth-Error-Type', error.constructor.name);
                request.res.set('X-Jwt-Auth-Error-Message', message);
                request.res.set('X-Jwt-Auth-Duration', profiler.duration);
            }
            return false;
        }
        return true;
    }
};
JwtAuthenticateGuard = tslib_1.__decorate([
    (0, common_1.Injectable)(),
    tslib_1.__param(0, (0, common_1.Inject)(sdk_nestjs_common_1.MXNEST_CONFIG_SERVICE)),
    tslib_1.__metadata("design:paramtypes", [Object])
], JwtAuthenticateGuard);
exports.JwtAuthenticateGuard = JwtAuthenticateGuard;
//# sourceMappingURL=jwt.authenticate.guard.js.map